<!DOCTYPE html>
<html>
<head>
	<title>Index</title>
</head>
<body>
	<h1>Index</h1>
	<p>This is a simple PHP web page.</p>
    <ul>
        <li><a href="http_redirect.php?key=value">link 1</a></li>
        <li><a href="https_redirect.php?key=value">link 2</a></li>
        <li><a href="no_redirect.php?key=value">link 3</a></li>
        <li><a href="500_error.php">link 4</a></li>
        <li><a href="401_error.php">link 5</a></li>
        <li><a href="/admin/">link 6</a></li>
    </ul>
</body>
</html>
